@@ -35,6 +35,12 @@ from .enums import (
 from .primitives import Container, PoolName, Region
 
 
+class UserInfo(BaseModel):
+    application_id: UUID
+    object_id: Optional[UUID]
+    upn: Optional[str]
+
+
 class EnumModel(BaseModel):
     @root_validator(pre=True)
     def exactly_one(cls: Any, values: Any) -> Any:
@@ -297,6 +303,7 @@ class TaskUnitConfig(BaseModel):
     target_options: Optional[List[str]]
     target_timeout: Optional[int]
     target_options_merge: Optional[bool]
+    target_workers: Optional[int]
     check_asan_log: Optional[bool]
     check_debugger: Optional[bool]
     check_retry_count: Optional[int]
@@ -703,3 +710,4 @@ class Task(BaseModel):
     end_time: Optional[datetime]
     events: Optional[List[TaskEventSummary]]
     nodes: Optional[List[NodeAssignment]]
+    user_info: Optional[UserInfo]
